@@ -5,6 +5,12 @@ export OFFLINE=${OFFLINE:=no}
 BIN_DIR=`dirname $0`
 . ${BIN_DIR}/common.sh
 
+
+if [ ! -e "${BIN_DIR}/../migrations/main/001_initial.py" ]; then
+  flask migration create initial
+fi
+
+
 if [ "${OFFLINE}" = "yes" ]; then
   setup no
 else
@@ -12,4 +18,3 @@ else
 fi
 flask migration run
 flask admin create
-flask gallery create
